BaseModel class abstract mixin

Constructors

BaseModel()
const

Properties

$className → String
The runtime type of this class as a String.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

equals(dynamic other) → bool
Compares the BaseModel with another BaseModel using the DeepCollectionEquality and returns true if they are equal.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sortedJson({bool includeNulls = false}) → Map<String, dynamic>
Returns a Json i.e. Map<String, dynamic> representation of the BaseModel, with the keys sorted alphabetically.
toJson({bool includeNulls = false}) → Map<String, dynamic>
Returns a Json i.e. Map<String, dynamic> representation of the BaseModel.
toJsonString() → String
Returns a JSON string representation of the BaseModel.
toString() → String
A string representation of this object.
override
toUrl() → Uri
Converts the current BaseModel to a Uri that can be used as a distinct identifier. The model must not be too large to avoid exceeding the maximum length of a URL.

Operators

operator ==(Object other) → bool
The equality operator.
inherited